#ifndef __PPROXY__H
#define __PPROXY__H

#include <stdarg.h>
#include <sys/socket.h>

struct http_var {
	char *name;
	char *value;
	struct http_var *next;
};

struct request {
    int client_fd;
    int server_fd;
    int cache_fd;
    int cmd;                            /* CMD_GET, CMD_POST, CMD_HEAD, ... */
    int server_code;                    /* 200=OK, 404=NF, ... */
    char *server;			/* www.penguin.cz */
    int port;				/* 80 */
    char *path;				/* /~mhi/pproxy/ */
    int http_version;			/* HTTP10, HTTP09, HTTP11 */
    int cachereq;                       /* Cache this request (0/1) */
    struct http_var *client_headers;
    struct http_var *server_headers;
    char *cache_file;                   /* /cache/www.penguin.cz/index.html */
};

#define CMD_UNKNOWN    0
#define CMD_HEAD       1
#define CMD_GET        2
#define CMD_POST       3

#define HTTP_UNKNOWNVERSION  0
#define HTTP_09              9
#define HTTP_10             10

/* main.c */

/* request.c */
extern int do_request(int s, struct sockaddr *r_addr, int addr_len);
extern struct request *get_header(int s);
extern struct request *new_request(int client_fd);
extern void free_request(struct request *req);
extern int http_process_data(struct request *req);

/* reqvar.c */
extern int req_set_client_header(struct request *req, char *name, char *value);
extern int req_set_server_header(struct request *req, char *name, char *value);
extern char* req_get_client_header(struct request *req, char *name);
extern char * req_get_server_header(struct request *req, char *name);

/* util.c */
extern unsigned long int resolve (char *hostname);
extern int sockgets (int socket, char *buf,int len);
extern int sockprintf (int socket, char *format,...);
extern int maketree(char *path);

/* signals.c */
extern int init_sighandlers(void);
 
#endif /* __PPROXY__H */
