#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <unistd.h>

#include "pproxy.h"


static int 
req_set_header (struct http_var **var, char *name, char *value)
{
  struct http_var *newvar, *curvar;
  char *newval;

  newval = strdup (value);
  if (!newval)
    return -1;

  //printf("%s=%s\n", name, value);

  curvar = *var;
  while (curvar)
    {
      if (!strcmp (curvar->name, name))
	{
	  if (curvar->value)
	    free (curvar->value);
	  curvar->value = newval;
	  return 0;
	}
      curvar = curvar->next;
    }

  newvar = (struct http_var *) malloc (sizeof (struct http_var));
  if (!newvar)
    {
      free (newval);
      return -1;
    }
  newvar->name = strdup (name);
  if (!newvar->name)
    {
      free (newvar);
      free (newval);
      return -1;
    }
  newvar->value = newval;
  newvar->next = *var;
  *var = newvar;
  return 0;
}

int 
req_set_client_header (struct request *req, char *name, char *value)
{
  return req_set_header (&req->client_headers, name, value);
}

int 
req_set_server_header (struct request *req, char *name, char *value)
{
  return req_set_header (&req->server_headers, name, value);
}

static char *
req_get_header (struct http_var *var, char *name)
{
  while (var)
    {
      if (!strcasecmp (var->name, name))
	return var->value;
      var = var->next;
    }
  return NULL;
}

char * 
req_get_client_header (struct request *req, char *name)
{
  return req_get_header (req->client_headers, name);
}

char * 
req_get_server_header (struct request *req, char *name)
{
  return req_get_header (req->server_headers, name);
}
